


#include "channelwidget.h"
#include <QDebug>

ChannelWidget::ChannelWidget(uint16_t deviceSerial, uint16_t channelNumber, struct eismultiplexer* multiplexer,
                             QWidget *parent)
    : QWidget(parent), deviceSerial(deviceSerial), channelNumber(channelNumber), multiplexer(multiplexer)
{
    // Create layout
    QHBoxLayout* layout = new QHBoxLayout(this);

    // Create label with device serial and channel number
    label = new QLabel(QString("Device %1, Channel %2").arg(deviceSerial).arg(channelNumber), this);
    layout->addWidget(label);

    // Create checkbox
    checkbox = new QCheckBox(this);
    layout->addWidget(checkbox);

    // Connect checkbox signal
    connect(checkbox, &QCheckBox::toggled, this, &ChannelWidget::onChannelToggled);

    // Set layout
    setLayout(layout);
}

ChannelWidget::~ChannelWidget()
{
    // Nothing to clean up
}

void ChannelWidget::onChannelToggled(bool checked)
{
    channel_t channelFlag = static_cast<channel_t>(1 << channelNumber);
    if (checked) {
        if (eismultiplexer_connect_channel(multiplexer, channelFlag) < 0) {
            qWarning() << "Failed to connect channel" << channelNumber << "on device" << deviceSerial;
            checkbox->setChecked(false);
        }
    } else {
        if (eismultiplexer_disconnect_channel(multiplexer, channelFlag) < 0) {
            qWarning() << "Failed to disconnect channel" << channelNumber << "on device" << deviceSerial;
            checkbox->setChecked(true);
        }
    }
}

